# Contributor Guide

Thank you for your interest in improving this project. This project is
open-source and welcomes contributions in the form of bug reports, feature
requests, and pull requests.

Here is a list of important resources for contributors:

- [Source Code](https://github.com/exoplanet-dev/jaxoplanet)
- [Documentation](https://jax.exoplanet.codes)
- [Issue Tracker](https://github.com/exoplanet-dev/jaxoplanet/issues)

## How to report a bug

Report bugs on the [Issue Tracker](https://github.com/exoplanet-dev/jaxoplanet/issues).

When filing an issue, make sure to answer these questions:

- Which operating system and Python version are you using?
- Which version of this project are you using?
- What did you do?
- What did you expect to see?
- What did you see instead?

The best way to get your bug fixed is to provide a test case, and/or steps to
reproduce the issue. In particular, please include a [Minimal, Reproducible
Example](https://stackoverflow.com/help/minimal-reproducible-example).

## How to request a feature

Feel free to request features on the [Issue
Tracker](https://github.com/exoplanet-dev/jaxoplanet/issues).

## How to test the project

```bash
python -m pip install nox
python -m nox -s test
```

## How to submit changes

Open a [Pull Request](https://github.com/exoplanet-dev/jaxoplanet/pulls).
